# <img alt="amset" src="https://raw.githubusercontent.com/hackingmaterials/amset/main/docs/src/amset_logo.png" width="250">

AMSET is a package for calculating electronic transport properties from
first-principles calculations.

- **Website (including documentation):** https://hackingmaterials.lbl.gov/amset/
- **Help/Support:** https://discuss.matsci.org/c/amset
- **Source:** https://github.com/hackingmaterials/amset

If you find AMSET useful, please consider citing [our paper](https://www.nature.com/articles/s41467-021-22440-5):

```
Ganose, A. M., Park, J., Faghaninia, A., Woods-Robinson, R., Persson, K. A., Jain, A.
Efficient calculation of carrier scattering rates from first principles.
Nat. Commun. 12, 2222 (2021)
```

Interested in contributing? See our [contribution guidelines](https://github.com/hackingmaterials/amset/blob/main/CONTRIBUTING.md)
